%% ===========================================================================
% Copyright (C):
%       1998-2000 by Telia Research AB, Lulea, Sweden
%                                                         All rights reserved.
% 
% Description   : Main VDSL simulation program with
%                 a graphical user interface. (GUI)
%
% File          : uiMain.m
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: uiMain.m,v 1.3 2002/06/06 15:01:37 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      1998-11-12 (ToNo) Created
%      1998-11-13 (ToNo) Modified to the split of experiment setup
%      1998-12-08 (DaB)  Updated
%      1998-12-21 (ToNo) Added test for matlab bug on reading numbers.
%      1998-12-21 (ToNo) Removed frequency axis stuff (is now in evalExperiment)
%      1998-12-22 (ToNo) Added more comments
%      1999-01-04 (ToNo) Adjusted window size to manage small screens better.
%      1998-01-14 (ToNo) Updated error message
%      1998-02-26 (ToNo) Made tt scenarios into a list
%      1999-03-25 (ToNo) Restructured the source (moved into subdir xdslcomm)
%      1999-08-25 (DaB)  Added lincode path
%      1999-10-03 (DaB)  Rewritten for new ex and gui struct
%      2000-04-05 (UvAn) New return value from etsi_tfplanHAM
%% ===========================================================================
global ex;
global gui;
global simures;

%% ===========================================================================
% Setup default gui struct
gui            = setupGUI;
gui.ttlist     = fsan_loops(gui.ttlist);

% Set up a specific start experiment (to have something for gui)
gui.scenario   = 'FSAN scenario FTTEx #1';         % Scenario to run
gui.vdslDuplex = 'VDSL-test';                      % Duplex method for VDSL

% Set up default experiment structures
ex.param       = setupParam(gui.vdslDuplex);       % Parameters
[ex.tfplist, ex.param.HAMBandName] = ...
	etsi_tfplanHAM([]);                        % Need a HAM band definition
ex.tfplist     = fsan_tfplansMISC(ex.tfplist);     % Get plans for alien noise
ex.tfplist     = fsan_noise(ex.tfplist);	   % Get FSAN noise models
ex.tfplist     = fsan_tfplansVDSL(ex.tfplist);     % Get test VDSL plans
ex.lclist      = setupLClist;
ex.clist       = etsi_cables([]);                  % Get ETSI (& ANSI) cables;
ex.tt          = getList(gui.ttlist,gui.scenario);

gui.PBO.maxlen = getMaxVDSLlength(ex.tt.topology,ex.tt.traffic);

%% ===========================================================================
% If available, include some user definitions
fid=fopen('userDefinitions.m','r');
if fid ~= -1,
    fclose(fid);
    userDefinitions;
end;

%% ===========================================================================
% Show setup and run from there
uiSetup;

