function IL=SDSLIL(loopno,freq,len)
%SDSLIL - Get get insertion loss given a SDSL loop, ft, and a length
%
% Parameter:    loopno     Loop number to test
% Parameter:    freq       Frequency for test [Hz]
% Parameter:    len        Length of loop [m]
% Returns:      IL         Insertion loss [dB]
%
% Example(s):
%               % Insertion loss @ 150kHz for Loop#4 with a length of 6104m:
%               SDSLIL(4,150e3,6104) 
%% ===========================================================================
 
%% ===========================================================================
% Copyright (C):
%       2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : B1, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: SDSLIL.m,v 1.1 2000/11/10 10:18:24 tono Exp $               %% ===========================================================================

%% ===========================================================================
% Change History
%      2000-07-18 (ToNo) Created
%% ===========================================================================
global ex;

scenario = sprintf('SDSL-Loop%d',loopno);
ttlist  = etsi_loopsSDSL([],len);   

tt      = getList(ttlist,scenario);     % Get the selected scenario
segs    = size(tt.topology);
Att     = getAtt(ex,1,segs(1),tt.topology,ex.param.frequency.f,ex.param.Zterm);
IL      = -Att(find(ex.param.frequency.f==freq));
