function [res] = ABCDshunt(f,R,C,L);
%ABCDshunt - Generate a ABCD matrix corresponding to a shunt
%
% Parameter:    f          Frequencies to use
%               R          The shunt R
%               C          The shunt C
%               L          The shunt L
% Returns:      res        The resulting ABCD matrix
%
% Example(s):
%
% Reference:
% 
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: ABCDshunt.m,v 1.1 2001/12/05 15:00:22 tono Exp $
%% ===========================================================================
% Change History
%      2001-11-10 (ToNo) Created
%% ===========================================================================

nf = size(f);

if nargin<4,
    jwL=inf;
else
    jwL=j*2*pi*f*L;
end;

if (nargin<3) | (C==0),
    jwC=0;
else
    jwC=j*2*pi*f*C;
end;

if R==0;
    R=inf;
end;
R=R*ones(nf);

OoZ= 1./R + jwC + 1./jwL;

res{1,1}=ones(nf);
res{1,2}=zeros(nf);
res{2,1}=OoZ;
res{2,2}=ones(nf);
