function  lens= etsi_loopsSDSLdeflen(modelstring,brate,lcname,loopno);
%% ===========================================================================
% etsi_loopsSDSLdeflen - Defines default values for ETSI SDSL testloops
%
% Parameter:    modelstring     Name of the noise model applied
%               brate           Considered bitrate
%               lcname          Linecode name
%               loopno          Vector with selected loop numbers
% Returns:      lens            Matrix of default testlooplengths 
%
% Reference: 
%               ETSI STC TM6 Helsinki 2000: WD22R3, WD19R3, and 002t22a0
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : B1, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot schmid (schmid@ftw.at)
%
% CVS:       $Id: etsi_loopsSDSLdeflen.m,v 1.1 2000/11/10 10:18:25 tono Exp $
%% ===========================================================================
% Change History
%      2000-10-25   (GS) Created
%      2000-11-08 (ToNo) Modified how loopno selection is handled
%% ===========================================================================

if nargin<3,
    error('defaultTestlooplengths: Not enough input arguments.');
end
 
if nargin<4
   loopno=[1:7]; % If not loopno give all numbers
end;

speeds=1e3*[384 512 768 1024 1280 1536 2048 2304];

speedindex=find(speeds==brate);
if isempty(speedindex)
   error('no default testloop lenght for the bitrate available');
end

if strncmp(lcname,'SDSL-sym',8)
   switch  modelstring 
   case 'Model SDSL Noise A'
         lengths_matrix=[2 4106 5563 5568 11064 3165 4698;
                         2 3535 4787 4789  9387 2646 3996;
                         2 2773 3747 3753  7153 1904 3062;
                         2 2439 3285 3291  6174 1547 2668;
                         2 2105 2829 2837  5193 1284 2266;
                         2 1820 2453 2455  4357 1052 1900;
                         2 1558 2046 2052  3285  748 1550;
                         2 1381 1815 1820  2789  583 1331]; 
    otherwise   % for all other noise models and also for 'Calculate' !!!
         lengths_matrix=[2 4773 6471 6477 13021 3859 5508;
                         2 4202 5692 5698 11344 3261 4814;
                         2 3392 4592 4596  8970 2536 3815;
                         2 3058 4135 4141  7990 2223 3403;
                         2 2725 3678 3684  7011 1816 3006;
                         2 2439 3285 3291  6174 1680 2673;
                         2 2135 2812 2820  4886 1426 2271;
                         2 1913 2509 2518  4257 1208 2010]; 
     end
end
  
if strncmp(lcname,'SDSL-asym',9)
   switch  modelstring 
   case 'Model SDSL Noise A'
         lengths_matrix=[2 4106 5563 5568 11064 3165 4698;
                         2 3535 4787 4789  9387 2646 3996;
                         2 2773 3747 3753  7153 1904 3062;
                         2 2439 3285 3291  6174 1547 2668;
                         2 2105 2829 2837  5193 1284 2266;
                         2 1820 2453 2455  4357 1052 1900;
                         2 1743 2264 2272  3618 1001 1726 ;
                         2 1494 1927 1937  2915  702 1402];

    otherwise   % for all other noise models and also for 'Calculate' !!!
         lengths_matrix=[2 4773 6471 6477 13021 3859 5508;
                         2 4202 5692 5698 11344 3261 4814;
                         2 3392 4592 4596  8970 2536 3815;
                         2 3058 4135 4141  7990 2223 3403;
                         2 2725 3678 3684  7011 1816 3006;
                         2 2439 3285 3291  6174 1680 2673;
                         2 2323 3030 3034  5189 1607 2389;
                         2 2075 2699 2705  4514 1387 2102]; 
     end
end

lens=lengths_matrix(speedindex,loopno);
