function tfplist = etsi_noisesADSL(tfplist);
%% ===========================================================================
%etsi_noisesADSL(tfplist) - Sets up the tfplans for some standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_noisesADSL(ex.tfplist);           Add to existing tfplist
%   tfplan=getList(ex.tfplist,...
%                 'ETSI-ADSL-FDDoverISDN Noise A') ;    Get this ADSL noise
%
%   ex.tfplist = etsi_noisesADSL([]);                   Create a new tfplist
%   tfplan=getList(ex.tfplist,,...
%                 'ETSI-ADSL-ECoverPOTS Noise C') ;     Get this ADSL noise
%
%  Mask definitions:
%    ETSI STC TM6 Draft RTS/TM-06006 rev 10a (ADSL), 2001-05
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : The FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: etsi_noisesADSL.m,v 1.5 2002/01/25 12:16:17 tono Exp $
%% ===========================================================================
% Change History
%      2001-07-04 (ToNo) Created
%      2001-07-05 (ToNo) Added all the ETSI ADSL noises 
%                        (provided by Ragnar Jonsson)
%                        Fixed a mask for same pair ISDN 4B3T (from DTAG)    
%% ===========================================================================

%% ===========================================================================
% Template, order important!

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	% Power back-off method (-=not applicable)
def_tfplan.PSD.PBO.param.len     = 1500;		% PBO parameter {length(m)}
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 0;
def_tfplan.timeDivision.up       = 1; % Time used in up resp. down lin
def_tfplan.timeDivision.down     = 1;
def_tfplan.timeDivision.sync     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';

%% ===========================================================================

% These data was automatically generated from data privided by
% Ragnar Jonsson (ragnar.jonsson@conexant.com)

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 14000 -20 30000 -21.5 45000 -24.1 64000 -27.7 105000 -27.6 204000 -28.7 253000 -29.4 255000 -26.7 412000 -27.8 1.104e+06 -27.8 4.543e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20.1 15000 -20 30000 -21.5 45000 -24.1 65000 -27.6 111000 -27.7 120000 -24.8 275000 -25.3 300000 -29.1 403000 -36 500000 -48.6 614000 -64.8 630000 -64.8 651000 -62.3 755000 -62.4 1.023e+06 -72.7 1.22e+06 -75.5 1.4e+06 -77.9 2.59e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 30000 -27.1 45000 -29.6 66000 -32.6 106000 -32.6 200000 -33.6 253000 -34.3 254000 -32.5 303000 -32.9 417000 -34.2 1.104e+06 -34.2 4.439e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 30000 -27.1 44000 -29.6 64000 -32.6 114000 -32.6 120000 -30.7 277000 -31.4 305000 -34.9 389000 -39.3 500000 -53.6 620000 -70.1 633000 -70.1 650000 -68.2 758000 -68.5 1.071e+06 -79.9 1.222e+06 -81.6 1.398e+06 -83.7 2.479e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15000 -25.6 30000 -27.2 45000 -29.6 62000 -32.6 107000 -32.6 203000 -33.6 253800 -34.3 254000 -32.5 300000 -32.8 409000 -34.2 1.104e+06 -34.2 1.703e+06 -53.6 2.162e+06 -66.2 2.387e+06 -63.7 2.52e+06 -63.6 2.677e+06 -65.5 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 45000 -29.6 62000 -32.6 114000 -32.7 120000 -30.7 200000 -31 276000 -31.4 300000 -34.6 377000 -38.7 470000 -47.8 802000 -45.4 1.024e+06 -45.6 1.309e+06 -47.8 1.587e+06 -52.3 1.9e+06 -63 2.011e+06 -76.8 2.283e+06 -63.7 2.492e+06 -63.7 2.716e+06 -66.1 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverISDN Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 93100 -79.9 209000 -51.9 253990 -38.4 254000 -29.9 1.104e+06 -29.9 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 120000 -27.9 276000 -27.9 614000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20 15000 -20 30000 -21.5 66000 -27.7 130000 -27.7 138000 -25.9 204000 -26.1 298000 -26.6 420000 -27.3 1.104e+06 -27.3 4.5e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 30000 -21.6 66000 -27.7 129000 -27.7 138000 -24.5 276000 -24.9 298000 -28.8 387000 -34.6 500000 -48.6 595000 -62.5 755000 -62.5 1.2e+06 -75.3 2.6e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 66000 -32.6 130000 -32.7 138000 -31.5 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 4.5e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.1 65000 -32.6 129000 -32.7 138000 -30.4 276000 -31 296000 -34.1 381000 -38.8 461000 -48.3 605000 -68.4 755000 -68.4 1.2e+06 -82 2.9e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.2 66000 -32.6 130000 -32.7 138000 -31.5 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 1.85e+06 -58.1 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 30000 -27.1 65000 -32.6 129000 -32.7 138000 -30.4 276000 -31 296000 -34.1 381000 -38.8 469000 -48 776000 -45.5 1.03e+06 -45.5 1.41e+06 -48.9 1.8e+06 -57.9 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverISDN Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 138000 -29.4 1.104e+06 -29.4 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -79.9 50000 -79.9 80000 -71.8 138000 -27.4 276000 -27.4 614000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15000 -20 30000 -21.6 45000 -24.1 64000 -27.6 137990 -27.7 138000 -26.1 277000 -26.8 407000 -27.8 1.106e+06 -27.8 4.544e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 24000 -20.9 30000 -21 45000 -23 60000 -24.7 138000 -24.9 151000 -28 207000 -28.7 300000 -30.3 358000 -32.8 407000 -36.7 500000 -48.6 594000 -62.3 755000 -62.3 1.059e+06 -73.7 1.221e+06 -75.5 1.4e+06 -77.9 2.532e+06 -96.2 3e+07 -96.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15000 -25.6 30000 -27.1 45000 -29.6 65000 -32.6 137990 -32.8 138000 -31.7 272000 -32.5 414000 -34.2 1.103e+06 -34.2 4.36e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 15000 -25.6 24000 -26.5 30000 -26.8 61000 -30.5 138000 -30.8 149000 -33 200000 -33.5 308000 -35.2 375000 -38.5 456000 -46.9 605000 -68.4 755000 -68.4 980000 -77.3 1.128e+06 -80.8 1.402e+06 -83.7 2.57e+06 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.8 15000 -25.6 30000 -27.2 45000 -29.7 63000 -32.6 137000 -32.8 139000 -31.7 294000 -32.7 417000 -34.2 1.11e+06 -34.2 2.16e+06 -66.1 2.4e+06 -63.6 2.55e+06 -63.8 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 2000 -25.8 15000 -25.6 22000 -26.4 30000 -26.8 45000 -28.8 60000 -30.5 138000 -30.7 150000 -33 206000 -33.6 338000 -35.7 477000 -47.8 788000 -45.4 1.064e+06 -45.5 1.5e+06 -50.1 1.8e+06 -58.6 2e+07 -101.6 3e+07 -101.6 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-FDDoverPOTS Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 80000 -62.4 137990 -34.1 138000 -29.9 1.104e+06 -29.9 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 25875 -27.9 138000 -27.9 307000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise A';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20 15000 -20 31000 -21.5 63000 -25.6 112000 -25.7 204000 -26.1 298000 -26.6 420000 -27.3 1.104e+06 -27.3 4.5e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15000 -20 22000 -20.8 29000 -20.8 61000 -24.4 138000 -24.5 153000 -28.2 220000 -28.9 315000 -30.8 387000 -34.6 461000 -43.4 595000 -62.5 755000 -62.5 1.2e+06 -75.3 2.6e+06 -97.8 3e+07 -97.8 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise B';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 31000 -27 63000 -31.3 112000 -31.3 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 4.5e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 22000 -26.6 29000 -26.6 61000 -30.3 138000 -30.4 153000 -33.2 220000 -33.9 315000 -35.5 387000 -39.5 461000 -48.3 605000 -68.4 755000 -68.4 1.2e+06 -82 2.9e+06 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise C';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.6 15000 -25.6 31000 -27 63000 -31.3 112000 -31.3 204000 -31.8 298000 -32.5 420000 -33.7 1.104e+06 -33.7 1.85e+06 -58.1 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.6 15000 -25.6 22000 -26.6 29000 -26.6 61000 -30.3 138000 -30.4 153000 -33.2 220000 -33.9 315000 -35.5 387000 -39.5 469000 -48 776000 -45.5 1.03e+06 -45.5 1.41e+06 -48.9 1.8e+06 -57.9 2.3e+07 -104.1 3e+07 -104.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-ECoverPOTS Noise D';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 25875 -29.4 1.104e+06 -29.4 3.093e+06 -79.9 4.545e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -87.4 3990 -87.4 4000 -82.4 25875 -27.4 138000 -27.4 307000 -79.9 1.221e+06 -79.9 1.63e+06 -99.9 3e+07 -99.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


def_tfplan.lcname = 'X-Theo';
def_tfplan.PSD.active.upstream   = [1e3 10e3];
def_tfplan.PSD.active.downstream = [1e3 10e3];


% The PSD for same pair ISDN
tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-SamePairISDN4B3T';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -48.7 5e3 -48.7 22.5e3 -44.7 40e3 -45.3 65e3 -47.4 80e3 -50.1 100e3 -59.5 122.5e3 -108.5 154.5e3 -126.1 170e3 -127  185e3 -131 200e3 -135 215e3 -140 250e3 -148 300e3 -144 400e3 -133 1000e3 -133 5e6 -186 30e6 -186] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tfplist=insertList(tfplist,tmp_tfplan);

% The same PSD compensated with 
% 10.^((ex.param.XTlevel.NEXT+15*log10(ex.param.frequency.f./1e6))/10)
% To fake in the same pair (do not work correctly - uses FSANadd!)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-SamePairISDN4B3T_comp';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -48.7 5e3 -48.7 22.5e3 -44.7 40e3 -45.3 65e3 -47.4 80e3 -50.1 100e3 -59.5 122.5e3 -108.5 154.5e3 -126.1 170e3 -127  185e3 -131 200e3 -135 215e3 -140 250e3 -148 300e3 -144 400e3 -133 1000e3 -133 5e6 -186 30e6 -186] ,''Log-Linear'',ex.param.frequency.f)./(10.^((ex.param.XTlevel.NEXT+15*log10(ex.param.frequency.f./1e6))/10))';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL-NoSamePairISDN';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -180 30e6 -180] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tfplist=insertList(tfplist,tmp_tfplan);
